
# Slot: type


Should generally be set to an ontology class defined term for 'book'.

URI: [biolink:book_type](https://w3id.org/biolink/vocab/book_type)


## Domain and Range

[Book](Book.md) &#8594;  <sub>1..1</sub> [String](types/String.md)

## Parents

 *  is_a: [publication➞type](publication_type.md)

## Children


## Used by

 * [Book](Book.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | rdf:type |
| **Exact Mappings:** | | alliancegenome:soTermId |
|  | | gff3:type |
|  | | gpi:DB_Object_Type |

